jedi: Static analysis tool providing IDE support for Python
===========================================================

Description
-----------

Jedi is a static analysis tool for Python that is typically used in
IDEs/editors plugins. Jedi has a focus on autocompletion and goto
functionality. Other features include refactoring, code search and
finding references.
